@@ -15,21 +15,22 @@
 #    under the License.
 
 import abc
+import collections
 import threading
 
-from concurrent import futures
-import jsonschema
-from jsonschema import exceptions as schema_exc
+from automaton import exceptions as machine_excp
+from automaton import machines
+import fasteners
+import futurist
+from oslo_serialization import jsonutils
 from oslo_utils import reflection
 from oslo_utils import timeutils
-import six
 
 from taskflow.engines.action_engine import executor
 from taskflow import exceptions as excp
 from taskflow import logging
 from taskflow.types import failure as ft
-from taskflow.types import timing as tt
-from taskflow.utils import lock_utils
+from taskflow.utils import schema_utils as su
 
 # NOTE(skudriashev): This is protocol states and events, which are not
 # related to task states.
@@ -45,29 +46,9 @@ EVENT = 'EVENT'
 # for).
 WAITING_STATES = (WAITING, PENDING)
 
-_ALL_STATES = (WAITING, PENDING, RUNNING, SUCCESS, FAILURE, EVENT)
-_STOP_TIMER_STATES = (RUNNING, SUCCESS, FAILURE)
-
-# Transitions that a request state can go through.
-_ALLOWED_TRANSITIONS = (
-    # Used when a executor starts to publish a request to a selected worker.
-    (WAITING, PENDING),
-    # When a request expires (isn't able to be processed by any worker).
-    (WAITING, FAILURE),
-    # Worker has started executing a request.
-    (PENDING, RUNNING),
-    # Worker failed to construct/process a request to run (either the worker
-    # did not transition to RUNNING in the given timeout or the worker itself
-    # had some type of failure before RUNNING started).
-    #
-    # Also used by the executor if the request was attempted to be published
-    # but that did publishing process did not work out.
-    (PENDING, FAILURE),
-    # Execution failed due to some type of remote failure.
-    (RUNNING, FAILURE),
-    # Execution succeeded & has completed.
-    (RUNNING, SUCCESS),
-)
+# Once these states have been entered a request can no longer be
+# automatically expired.
+STOP_TIMER_STATES = (RUNNING, SUCCESS, FAILURE)
 
 # Remote task actions.
 EXECUTE = 'execute'
@@ -93,26 +74,86 @@ QUEUE_EXPIRE_TIMEOUT = REQUEST_TIMEOUT
 # Workers notify period.
 NOTIFY_PERIOD = 5
 
+# When a worker hasn't notified in this many seconds, it will get expired from
+# being used/targeted for further work.
+EXPIRES_AFTER = 60
+
 # Message types.
 NOTIFY = 'NOTIFY'
 REQUEST = 'REQUEST'
 RESPONSE = 'RESPONSE'
 
-# Special jsonschema validation types/adjustments.
-_SCHEMA_TYPES = {
-    # See: https://github.com/Julian/jsonschema/issues/148
-    'array': (list, tuple),
-}
+# Object that denotes nothing (none can actually be valid).
+NO_RESULT = object()
 
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Message(object):
+def make_an_event(new_state):
+    """Turns a new/target state into an event name."""
+    return ('on_%s' % new_state).lower()
+
+
+def build_a_machine(freeze=True):
+    """Builds a state machine that requests are allowed to go through."""
+
+    m = machines.FiniteMachine()
+    for st in (WAITING, PENDING, RUNNING):
+        m.add_state(st)
+    for st in (SUCCESS, FAILURE):
+        m.add_state(st, terminal=True)
+
+    # When a executor starts to publish a request to a selected worker but the
+    # executor has not recved confirmation from that worker that anything has
+    # happened yet.
+    m.default_start_state = WAITING
+    m.add_transition(WAITING, PENDING, make_an_event(PENDING))
+
+    # When a request expires (isn't able to be processed by any worker).
+    m.add_transition(WAITING, FAILURE, make_an_event(FAILURE))
+
+    # Worker has started executing a request.
+    m.add_transition(PENDING, RUNNING, make_an_event(RUNNING))
+
+    # Worker failed to construct/process a request to run (either the worker
+    # did not transition to RUNNING in the given timeout or the worker itself
+    # had some type of failure before RUNNING started).
+    #
+    # Also used by the executor if the request was attempted to be published
+    # but that did publishing process did not work out.
+    m.add_transition(PENDING, FAILURE, make_an_event(FAILURE))
+
+    # Execution failed due to some type of remote failure.
+    m.add_transition(RUNNING, FAILURE, make_an_event(FAILURE))
+
+    # Execution succeeded & has completed.
+    m.add_transition(RUNNING, SUCCESS, make_an_event(SUCCESS))
+
+    # No further changes allowed.
+    if freeze:
+        m.freeze()
+    return m
+
+
+def failure_to_dict(failure):
+    """Attempts to convert a failure object into a jsonifyable dictionary."""
+    failure_dict = failure.to_dict()
+    try:
+        # it's possible the exc_args can't be serialized as JSON
+        # if that's the case, just get the failure without them
+        jsonutils.dumps(failure_dict)
+        return failure_dict
+    except (TypeError, ValueError):
+        return failure.to_dict(include_args=False)
+
+
+class Message(object, metaclass=abc.ABCMeta):
     """Base class for all message types."""
 
-    def __str__(self):
-        return "<%s> %s" % (self.TYPE, self.to_dict())
+    def __repr__(self):
+        return ("<%s object at 0x%x with contents %s>"
+                % (reflection.get_class_name(self, fully_qualified=False),
+                   id(self), self.to_dict()))
 
     @abc.abstractmethod
     def to_dict(self):
@@ -156,6 +197,14 @@ class Notify(Message):
     def __init__(self, **data):
         self._data = data
 
+    @property
+    def topic(self):
+        return self._data.get('topic')
+
+    @property
+    def tasks(self):
+        return self._data.get('tasks')
+
     def to_dict(self):
         return self._data
 
@@ -166,16 +215,25 @@ class Notify(Message):
         else:
             schema = cls.SENDER_SCHEMA
         try:
-            jsonschema.validate(data, schema, types=_SCHEMA_TYPES)
-        except schema_exc.ValidationError as e:
+            su.schema_validate(data, schema)
+        except su.ValidationError as e:
+            cls_name = reflection.get_class_name(cls, fully_qualified=False)
             if response:
-                raise excp.InvalidFormat("%s message response data not of the"
-                                         " expected format: %s"
-                                         % (cls.TYPE, e.message), e)
+                excp.raise_with_cause(excp.InvalidFormat,
+                                      "%s message response data not of the"
+                                      " expected format: %s" % (cls_name,
+                                                                e.message),
+                                      cause=e)
             else:
-                raise excp.InvalidFormat("%s message sender data not of the"
-                                         " expected format: %s"
-                                         % (cls.TYPE, e.message), e)
+                excp.raise_with_cause(excp.InvalidFormat,
+                                      "%s message sender data not of the"
+                                      " expected format: %s" % (cls_name,
+                                                                e.message),
+                                      cause=e)
+
+
+_WorkUnit = collections.namedtuple('_WorkUnit', ['task_cls', 'task_name',
+                                                 'action', 'arguments'])
 
 
 class Request(Message):
@@ -184,6 +242,21 @@ class Request(Message):
     Every request is created in the WAITING state and is expired within the
     given timeout if it does not transition out of the (WAITING, PENDING)
     states.
+
+    State machine a request goes through as it progresses (or expires)::
+
+        +------------+------------+---------+----------+---------+
+        |   Start    |   Event    |   End   | On Enter | On Exit |
+        +------------+------------+---------+----------+---------+
+        | FAILURE[$] |     .      |    .    |    .     |    .    |
+        |  PENDING   | on_failure | FAILURE |    .     |    .    |
+        |  PENDING   | on_running | RUNNING |    .     |    .    |
+        |  RUNNING   | on_failure | FAILURE |    .     |    .    |
+        |  RUNNING   | on_success | SUCCESS |    .     |    .    |
+        | SUCCESS[$] |     .      |    .    |    .     |    .    |
+        | WAITING[^] | on_failure | FAILURE |    .     |    .    |
+        | WAITING[^] | on_pending | PENDING |    .     |    .    |
+        +------------+------------+---------+----------+---------+
     """
 
     #: String constant representing this message type.
@@ -217,7 +290,7 @@ class Request(Message):
             },
             'action': {
                 "type": "string",
-                "enum": list(six.iterkeys(ACTION_TO_EVENT)),
+                "enum": list(ACTION_TO_EVENT.keys()),
             },
             # Keyword arguments that end up in the revert() or execute()
             # method of the remote task.
@@ -228,44 +301,32 @@ class Request(Message):
         'required': ['task_cls', 'task_name', 'task_version', 'action'],
     }
 
-    def __init__(self, task, uuid, action, arguments, timeout, **kwargs):
-        self._task = task
-        self._uuid = uuid
+    def __init__(self, task, uuid, action,
+                 arguments, timeout=REQUEST_TIMEOUT, result=NO_RESULT,
+                 failures=None):
         self._action = action
         self._event = ACTION_TO_EVENT[action]
         self._arguments = arguments
-        self._kwargs = kwargs
-        self._watch = tt.StopWatch(duration=timeout).start()
-        self._state = WAITING
+        self._result = result
+        self._failures = failures
+        self._watch = timeutils.StopWatch(duration=timeout).start()
         self._lock = threading.Lock()
-        self._created_on = timeutils.utcnow()
-        self._result = futures.Future()
-        self._result.atom = task
-        self._notifier = task.notifier
+        self._machine = build_a_machine()
+        self._machine.initialize()
+        self.task = task
+        self.uuid = uuid
+        self.created_on = timeutils.now()
+        self.future = futurist.Future()
+        self.future.atom = task
 
     @property
-    def result(self):
-        return self._result
+    def current_state(self):
+        """Current state the request is in."""
+        return self._machine.current_state
 
-    @property
-    def notifier(self):
-        return self._notifier
-
-    @property
-    def uuid(self):
-        return self._uuid
-
-    @property
-    def task(self):
-        return self._task
-
-    @property
-    def state(self):
-        return self._state
-
-    @property
-    def created_on(self):
-        return self._created_on
+    def set_result(self, result):
+        """Sets the responses futures result."""
+        self.future.set_result((self._event, result))
 
     @property
     def expired(self):
@@ -278,7 +339,7 @@ class Request(Message):
         state for more then the given timeout (it is not considered to be
         expired in any other state).
         """
-        if self._state in WAITING_STATES:
+        if self._machine.current_state in WAITING_STATES:
             return self._watch.expired()
         return False
 
@@ -290,28 +351,24 @@ class Request(Message):
         then be reconstituted by the receiver).
         """
         request = {
-            'task_cls': reflection.get_class_name(self._task),
-            'task_name': self._task.name,
-            'task_version': self._task.version,
+            'task_cls': reflection.get_class_name(self.task),
+            'task_name': self.task.name,
+            'task_version': self.task.version,
             'action': self._action,
             'arguments': self._arguments,
         }
-        if 'result' in self._kwargs:
-            result = self._kwargs['result']
+        if self._result is not NO_RESULT:
+            result = self._result
             if isinstance(result, ft.Failure):
-                request['result'] = ('failure', result.to_dict())
+                request['result'] = ('failure', failure_to_dict(result))
             else:
                 request['result'] = ('success', result)
-        if 'failures' in self._kwargs:
-            failures = self._kwargs['failures']
+        if self._failures:
             request['failures'] = {}
-            for task, failure in six.iteritems(failures):
-                request['failures'][task] = failure.to_dict()
+            for atom_name, failure in self._failures.items():
+                request['failures'][atom_name] = failure_to_dict(failure)
         return request
 
-    def set_result(self, result):
-        self.result.set_result((self._event, result))
-
     def transition_and_log_error(self, new_state, logger=None):
         """Transitions *and* logs an error if that transitioning raises.
 
@@ -332,37 +389,88 @@ class Request(Message):
                         new_state, exc_info=True)
         return moved
 
-    @lock_utils.locked
+    @fasteners.locked
     def transition(self, new_state):
         """Transitions the request to a new state.
 
         If transition was performed, it returns True. If transition
-        should was ignored, it returns False. If transition was not
+        was ignored, it returns False. If transition was not
         valid (and will not be performed), it raises an InvalidState
         exception.
         """
-        old_state = self._state
+        old_state = self._machine.current_state
         if old_state == new_state:
             return False
-        pair = (old_state, new_state)
-        if pair not in _ALLOWED_TRANSITIONS:
+        try:
+            self._machine.process_event(make_an_event(new_state))
+        except (machine_excp.NotFound, machine_excp.InvalidState) as e:
             raise excp.InvalidState("Request transition from %s to %s is"
-                                    " not allowed" % pair)
-        if new_state in _STOP_TIMER_STATES:
-            self._watch.stop()
-        self._state = new_state
-        LOG.debug("Transitioned '%s' from %s state to %s state", self,
-                  old_state, new_state)
-        return True
+                                    " not allowed: %s" % (old_state,
+                                                          new_state, e))
+        else:
+            if new_state in STOP_TIMER_STATES:
+                self._watch.stop()
+            LOG.debug("Transitioned '%s' from %s state to %s state", self,
+                      old_state, new_state)
+            return True
 
     @classmethod
     def validate(cls, data):
         try:
-            jsonschema.validate(data, cls.SCHEMA, types=_SCHEMA_TYPES)
-        except schema_exc.ValidationError as e:
-            raise excp.InvalidFormat("%s message response data not of the"
-                                     " expected format: %s"
-                                     % (cls.TYPE, e.message), e)
+            su.schema_validate(data, cls.SCHEMA)
+        except su.ValidationError as e:
+            cls_name = reflection.get_class_name(cls, fully_qualified=False)
+            excp.raise_with_cause(excp.InvalidFormat,
+                                  "%s message response data not of the"
+                                  " expected format: %s" % (cls_name,
+                                                            e.message),
+                                  cause=e)
+        else:
+            # Validate all failure dictionaries that *may* be present...
+            failures = []
+            if 'failures' in data:
+                failures.extend(data['failures'].values())
+            result = data.get('result')
+            if result is not None:
+                result_data_type, result_data = result
+                if result_data_type == 'failure':
+                    failures.append(result_data)
+            for fail_data in failures:
+                ft.Failure.validate(fail_data)
+
+    @staticmethod
+    def from_dict(data, task_uuid=None):
+        """Parses **validated** data into a work unit.
+
+        All :py:class:`~taskflow.types.failure.Failure` objects that have been
+        converted to dict(s) on the remote side will now converted back
+        to py:class:`~taskflow.types.failure.Failure` objects.
+        """
+        task_cls = data['task_cls']
+        task_name = data['task_name']
+        action = data['action']
+        arguments = data.get('arguments', {})
+        result = data.get('result')
+        failures = data.get('failures')
+        # These arguments will eventually be given to the task executor
+        # so they need to be in a format it will accept (and using keyword
+        # argument names that it accepts)...
+        arguments = {
+            'arguments': arguments,
+        }
+        if task_uuid is not None:
+            arguments['task_uuid'] = task_uuid
+        if result is not None:
+            result_data_type, result_data = result
+            if result_data_type == 'failure':
+                arguments['result'] = ft.Failure.from_dict(result_data)
+            else:
+                arguments['result'] = result_data
+        if failures is not None:
+            arguments['failures'] = {}
+            for task, fail_data in failures.items():
+                arguments['failures'][task] = ft.Failure.from_dict(fail_data)
+        return _WorkUnit(task_cls, task_name, action, arguments)
 
 
 class Response(Message):
@@ -377,7 +485,7 @@ class Response(Message):
         'properties': {
             'state': {
                 "type": "string",
-                "enum": list(_ALL_STATES),
+                "enum": list(build_a_machine().states) + [EVENT],
             },
             'data': {
                 "anyOf": [
@@ -430,8 +538,8 @@ class Response(Message):
     }
 
     def __init__(self, state, **data):
-        self._state = state
-        self._data = data
+        self.state = state
+        self.data = data
 
     @classmethod
     def from_dict(cls, data):
@@ -441,22 +549,21 @@ class Response(Message):
             data['result'] = ft.Failure.from_dict(data['result'])
         return cls(state, **data)
 
-    @property
-    def state(self):
-        return self._state
-
-    @property
-    def data(self):
-        return self._data
-
     def to_dict(self):
-        return dict(state=self._state, data=self._data)
+        return dict(state=self.state, data=self.data)
 
     @classmethod
     def validate(cls, data):
         try:
-            jsonschema.validate(data, cls.SCHEMA, types=_SCHEMA_TYPES)
-        except schema_exc.ValidationError as e:
-            raise excp.InvalidFormat("%s message response data not of the"
-                                     " expected format: %s"
-                                     % (cls.TYPE, e.message), e)
+            su.schema_validate(data, cls.SCHEMA)
+        except su.ValidationError as e:
+            cls_name = reflection.get_class_name(cls, fully_qualified=False)
+            excp.raise_with_cause(excp.InvalidFormat,
+                                  "%s message response data not of the"
+                                  " expected format: %s" % (cls_name,
+                                                            e.message),
+                                  cause=e)
+        else:
+            state = data['state']
+            if state == FAILURE and 'result' in data:
+                ft.Failure.validate(data['result'])
