@@ -17,6 +17,7 @@
 import contextlib
 import datetime
 import functools
+import re
 import string
 import threading
 import time
@@ -30,8 +31,6 @@ from oslo_utils import timeutils
 from oslo_utils import uuidutils
 from redis import exceptions as redis_exceptions
 from redis import sentinel
-import six
-from six.moves import range as compat_range
 
 from taskflow import exceptions as exc
 from taskflow.jobs import base
@@ -265,6 +264,7 @@ class RedisJobBoard(base.JobBoard):
         ('port', int),
 
         # See: http://redis.io/commands/auth
+        ('username', str),
         ('password', str),
 
         # Data encoding/decoding + error handling
@@ -559,6 +559,18 @@ return cmsgpack.pack(result)
                                                           ut-were-afraid-to-ask
     """
 
+    @classmethod
+    def _parse_sentinel(cls, sentinel):
+        # IPv6 (eg. [::1]:6379 )
+        match = re.search(r'^\[(\S+)\]:(\d+)$', sentinel)
+        if match:
+            return (match[1], int(match[2]))
+        # IPv4 or hostname (eg. 127.0.0.1:6379 or localhost:6379)
+        match = re.search(r'^(\S+):(\d+)$', sentinel)
+        if match:
+            return (match[1], int(match[2]))
+        raise ValueError('Malformed sentinel server format')
+
     @classmethod
     def _make_client(cls, conf):
         client_conf = {}
@@ -569,15 +581,16 @@ return cmsgpack.pack(result)
                 else:
                     client_conf[key] = conf[key]
         if conf.get('sentinel') is not None:
-            sentinel_conf = {}
-            # sentinel do not have ssl kwargs
-            for key in client_conf:
-                if 'ssl' not in key:
-                    sentinel_conf[key] = client_conf[key]
-            s = sentinel.Sentinel([(sentinel_conf.pop('host'),
-                                    sentinel_conf.pop('port'))],
-                                  sentinel_kwargs=conf.get('sentinel_kwargs'),
-                                  **sentinel_conf)
+            sentinels = [(client_conf.pop('host'), client_conf.pop('port'))]
+            for fallback in conf.get('sentinel_fallbacks', []):
+                sentinels.append(cls._parse_sentinel(fallback))
+            sentinel_kwargs = conf.get('sentinel_kwargs', {})
+            for key in ('username', 'password', 'socket_timeout'):
+                if key in conf:
+                    sentinel_kwargs.setdefault(key, conf[key])
+            s = sentinel.Sentinel(sentinels,
+                                  sentinel_kwargs=sentinel_kwargs,
+                                  **client_conf)
             return s.master_for(conf['sentinel'])
         else:
             return ru.RedisClient(**client_conf)
@@ -620,9 +633,9 @@ return cmsgpack.pack(result)
         key_pieces = [key_piece]
         if more_key_pieces:
             key_pieces.extend(more_key_pieces)
-        for i in compat_range(0, len(namespace_pieces)):
+        for i in range(0, len(namespace_pieces)):
             namespace_pieces[i] = misc.binary_encode(namespace_pieces[i])
-        for i in compat_range(0, len(key_pieces)):
+        for i in range(0, len(key_pieces)):
             key_pieces[i] = misc.binary_encode(key_pieces[i])
         namespace = b"".join(namespace_pieces)
         key = self.KEY_PIECE_SEP.join(key_pieces)
@@ -696,7 +709,7 @@ return cmsgpack.pack(result)
                     'already_claimed': self.SCRIPT_ALREADY_CLAIMED,
                 }
                 prepared_scripts = {}
-                for n, raw_script_tpl in six.iteritems(self.SCRIPT_TEMPLATES):
+                for n, raw_script_tpl in self.SCRIPT_TEMPLATES.items():
                     script_tpl = string.Template(raw_script_tpl)
                     script_blob = script_tpl.substitute(**script_params)
                     script = self._client.register_script(script_blob)
@@ -761,7 +774,7 @@ return cmsgpack.pack(result)
             })
         with _translate_failures():
             raw_posting = self._dumps(posting)
-            raw_job_uuid = six.b(job_uuid)
+            raw_job_uuid = job_uuid.encode('latin-1')
             was_posted = bool(self._client.hsetnx(self.listings_key,
                                                   raw_job_uuid, raw_posting))
             if not was_posted:
@@ -813,7 +826,7 @@ return cmsgpack.pack(result)
         with _translate_failures():
             raw_postings = self._client.hgetall(self.listings_key)
         postings = []
-        for raw_job_key, raw_posting in six.iteritems(raw_postings):
+        for raw_job_key, raw_posting in raw_postings.items():
             try:
                 job_data = self._loads(raw_posting)
                 try:
