@@ -28,9 +28,9 @@ from kazoo.protocol import states as k_states
 from kazoo.recipe import watchers
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
+from oslo_utils import strutils
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import six
 
 from taskflow.conductors import base as c_base
 from taskflow import exceptions as excp
@@ -373,7 +373,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
             if ensure_fresh:
                 self._force_refresh()
             with self._job_cond:
-                return sorted(six.itervalues(self._known_jobs))
+                return sorted(self._known_jobs.values())
 
     def _force_refresh(self):
         try:
@@ -479,7 +479,7 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
         investigate_paths = []
         pending_removals = []
         with self._job_cond:
-            for path in six.iterkeys(self._known_jobs):
+            for path in self._known_jobs.keys():
                 if path not in child_paths:
                     pending_removals.append(path)
         for path in child_paths:
@@ -830,7 +830,8 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
             excp.raise_with_cause(excp.JobFailure,
                                   "Failed to connect to zookeeper")
         try:
-            if self._conf.get('check_compatible', True):
+            if strutils.bool_from_string(
+                    self._conf.get('check_compatible'), default=True):
                 kazoo_utils.check_compatible(self._client, self.MIN_ZK_VERSION)
             if self._worker is None and self._emit_notifications:
                 self._worker = futurist.ThreadPoolExecutor(max_workers=1)
@@ -855,4 +856,4 @@ class ZookeeperJobBoard(base.NotifyingJobBoard):
                                       "Failed to do post-connection"
                                       " initialization", cause=exc)
             finally:
-                del(exc_type, exc, exc_tb)
+                del (exc_type, exc, exc_tb)
