@@ -106,12 +106,14 @@ class RedisJobboardTest(test.TestCase, base.BoardTestMixin):
     def test__make_client(self):
         conf = {'host': '127.0.0.1',
                 'port': 6379,
+                'username': 'default',
                 'password': 'secret',
                 'namespace': 'test'
                 }
         test_conf = {
             'host': '127.0.0.1',
             'port': 6379,
+            'username': 'default',
             'password': 'secret',
         }
         with mock.patch('taskflow.utils.redis_utils.RedisClient') as mock_ru:
@@ -121,17 +123,75 @@ class RedisJobboardTest(test.TestCase, base.BoardTestMixin):
     def test__make_client_sentinel(self):
         conf = {'host': '127.0.0.1',
                 'port': 26379,
+                'username': 'default',
                 'password': 'secret',
                 'namespace': 'test',
                 'sentinel': 'mymaster',
-                'sentinel_kwargs': {'password': 'senitelsecret'}}
+                'sentinel_kwargs': {
+                    'username': 'sentineluser',
+                    'password': 'senitelsecret'
+                }}
         with mock.patch('redis.sentinel.Sentinel') as mock_sentinel:
             impl_redis.RedisJobBoard('test-board', conf)
             test_conf = {
+                'username': 'default',
                 'password': 'secret',
             }
             mock_sentinel.assert_called_once_with(
                 [('127.0.0.1', 26379)],
-                sentinel_kwargs={'password': 'senitelsecret'},
+                sentinel_kwargs={
+                    'username': 'sentineluser',
+                    'password': 'senitelsecret'
+                },
+                **test_conf)
+            mock_sentinel().master_for.assert_called_once_with('mymaster')
+
+    def test__make_client_sentinel_fallbacks(self):
+        conf = {'host': '127.0.0.1',
+                'port': 26379,
+                'username': 'default',
+                'password': 'secret',
+                'namespace': 'test',
+                'sentinel': 'mymaster',
+                'sentinel_fallbacks': [
+                    '[::1]:26379', '127.0.0.2:26379', 'localhost:26379'
+                ]}
+        with mock.patch('redis.sentinel.Sentinel') as mock_sentinel:
+            impl_redis.RedisJobBoard('test-board', conf)
+            test_conf = {
+                'username': 'default',
+                'password': 'secret',
+            }
+            mock_sentinel.assert_called_once_with(
+                [('127.0.0.1', 26379), ('::1', 26379),
+                 ('127.0.0.2', 26379), ('localhost', 26379)],
+                sentinel_kwargs={
+                    'username': 'default',
+                    'password': 'secret'
+                },
+                **test_conf)
+            mock_sentinel().master_for.assert_called_once_with('mymaster')
+
+    def test__make_client_sentinel_ssl(self):
+        conf = {'host': '127.0.0.1',
+                'port': 26379,
+                'username': 'default',
+                'password': 'secret',
+                'namespace': 'test',
+                'sentinel': 'mymaster',
+                'ssl': True,
+                'ssl_ca_certs': '/etc/ssl/certs'}
+        with mock.patch('redis.sentinel.Sentinel') as mock_sentinel:
+            impl_redis.RedisJobBoard('test-board', conf)
+            test_conf = {
+                'username': 'default',
+                'password': 'secret',
+                'ssl': True,
+                'ssl_ca_certs': '/etc/ssl/certs',
+            }
+            mock_sentinel.assert_called_once_with(
+                [('127.0.0.1', 26379)],
+                sentinel_kwargs={
+                    'username': 'default', 'password': 'secret'},
                 **test_conf)
             mock_sentinel().master_for.assert_called_once_with('mymaster')
